@@ -1,5 +1,5 @@
 /* Openoffice.org-voikko: Finnish linguistic extension for OpenOffice.org
- * Copyright (C) 2007 - 2009 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2007 - 2010 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -221,10 +221,14 @@ uno::Any PropertyManager::readFromRegistry(const OUString group, const OUString
 	throw (beans::UnknownPropertyException) {
 	uno::Reference<uno::XInterface> rootView =
 		getRegistryProperties(group, compContext);
+	if (!rootView.is()) {
+		VOIKKO_DEBUG("ERROR: failed to obtain rootView");
+		throw beans::UnknownPropertyException();
+	}
 	uno::Reference<beans::XHierarchicalPropertySet> propSet(rootView, uno::UNO_QUERY);
 	if (!propSet.is()) {
 		VOIKKO_DEBUG("ERROR: failed to obtain propSet");
-		throw new beans::UnknownPropertyException();
+		throw beans::UnknownPropertyException();
 	}
 	uno::Any value = propSet->getHierarchicalPropertyValue(key);
 	return value;
@@ -326,7 +330,6 @@ void PropertyManager::resetValues(const uno::Sequence<beans::PropertyValue> & va
 
 void PropertyManager::setValue(const beans::PropertyValue & value) {
 	sal_Bool bValue = sal_False;
-	sal_Int16 iValue = 0;
 	int vbValue = 0;
 	// VOIKKO_DEBUG_2("PropertyManager::setValue: name %s", OU2DEBUG(value.Name));
 	if (value.Name == A2OU("IsSpellWithDigits")) {
@@ -349,6 +352,7 @@ void PropertyManager::setValue(const beans::PropertyValue & value) {
 		voikko_set_bool_option(voikko_handle, VOIKKO_OPT_ACCEPT_ALL_UPPERCASE, vbValue);
 	}
 	else if (value.Name == A2OU("HyphMinLeading")) {
+		sal_Int16 iValue;
 		if (value.Value >>= iValue) {
 			hyphMinLeading = iValue;
 			// VOIKKO_DEBUG_2("PropertyManager::setValue: value %i", iValue);
@@ -356,6 +360,7 @@ void PropertyManager::setValue(const beans::PropertyValue & value) {
 		}
 	}
 	else if (value.Name == A2OU("HyphMinTrailing")) {
+		sal_Int16 iValue;
 		if (value.Value >>= iValue) {
 			hyphMinTrailing = iValue;
 			// VOIKKO_DEBUG_2("PropertyManager::setValue: value %i", iValue);
@@ -363,6 +368,7 @@ void PropertyManager::setValue(const beans::PropertyValue & value) {
 		}
 	}
 	else if (value.Name == A2OU("HyphMinWordLength")) {
+		sal_Int16 iValue;
 		if (value.Value >>= iValue) {
 			hyphMinWordLength = iValue;
 			// VOIKKO_DEBUG_2("PropertyManager::setValue: value %i", iValue);
